@@ -172,7 +172,7 @@ KateMainWindow::KateMainWindow (KConfig *sconfig, const QString &sgroup)
   setXMLFile( "kateui.rc" );
   createShellGUI ( true );
 
-  kDebug() << "****************************************************************************" << sconfig;
+  //kDebug() << "****************************************************************************" << sconfig;
 
   // register mainwindow in app
   KateApp::self()->addMainWindow (this);
@@ -264,12 +264,13 @@ void KateMainWindow::setupMainWindow ()
   m_fileList->setDragEnabled(true);
   m_fileList->setDragDropMode(QAbstractItemView::InternalMove);
   m_fileList->setDropIndicatorShown(true);
+  m_fileList->setSelectionMode(QAbstractItemView::ExtendedSelection);
 #ifdef __GNUC__
 #warning I do not like it, it looks like a hack, search for a better way, but for now it should work. (Even on windows most lisviews, except exploder are single click) (jowenn)
 #endif
-  if (!style()->styleHint(QStyle::SH_ItemView_ActivateItemOnSingleClick, 0, m_fileList))
+  if (!style()->styleHint(QStyle::SH_ItemView_ActivateItemOnSingleClick, 0, m_fileList) )
   {
-    kDebug() << "HACK:***********************CONNECTING CLICKED***************************";
+    //kDebug() << "HACK:***********************CONNECTING CLICKED***************************";
     connect(m_fileList, SIGNAL(clicked(const QModelIndex&)), m_documentModel, SLOT(opened(const QModelIndex&)));
     connect(m_fileList, SIGNAL(clicked(const QModelIndex&)), m_viewManager, SLOT(activateDocument(const QModelIndex &)));
   }
@@ -278,15 +279,13 @@ void KateMainWindow::setupMainWindow ()
   connect(m_fileList, SIGNAL(customContextMenuRequested(const QPoint &)), this, SLOT(showFileListPopup(const QPoint&)));
   connect(m_fileList, SIGNAL(closeDocument(KTextEditor::Document*)),m_viewManager,SLOT(slotDocumentClose(KTextEditor::Document*)));
   connect(m_fileList, SIGNAL(closeOtherDocument(KTextEditor::Document*)),this,SLOT(slotDocumentCloseOther(KTextEditor::Document*)));
+  connect(m_fileList, SIGNAL(closeSelectedDocument(QList<KTextEditor::Document*>)),
+                      this, SLOT(slotDocumentCloseSelected(QList<KTextEditor::Document*>)));
+  connect(m_fileList, SIGNAL(saveSelectedDocument(QList<KTextEditor::Document*>)),
+                      KateDocManager::self(), SLOT(saveSelected(QList<KTextEditor::Document*>)));
   //filelist = new KateFileList (this, m_viewManager, ft);
 //   m_fileList->readConfig(KConfigGroup(KGlobal::config(), "FileList"));
 
-#if 0
-  KateMDI::ToolView *t = createToolView("kate_fileselector", KMultiTabBar::Left, SmallIcon("document-open"), i18n("Filesystem Browser"));
-  fileselector = new KateFileSelector( this, m_viewManager, t, "operator");
-  connect(fileselector->dirOperator(), SIGNAL(fileSelected(const KFileItem&)), this, SLOT(fileSelected(const KFileItem&)));
-#endif
-
   // make per default the filelist visible, if we are in session restore, katemdi will skip this ;)
   showToolView (ft);
 }
@@ -320,7 +319,7 @@ void KateMainWindow::setupActions()
   a->setText( i18n("Close Orphaned") );
   connect( a, SIGNAL( triggered() ), KateDocManager::self(), SLOT( closeOrphaned() ) );
   a->setWhatsThis(i18n("Close all documents in the file list that could not be reopened, because they are not accessible anymore."));
-  
+
   actionCollection()->addAction( KStandardAction::Close, "file_close", m_viewManager, SLOT( slotDocumentClose() ) )
   ->setWhatsThis(i18n("Close the current document."));
 
@@ -334,8 +333,10 @@ void KateMainWindow::setupActions()
   connect( a, SIGNAL( triggered() ), this, SLOT( slotDocumentCloseAll() ) );
   a->setWhatsThis(i18n("Close all open documents."));
 
-  actionCollection()->addAction( KStandardAction::Quit, "file_quit", this, SLOT( slotFileQuit() ) )
-  ->setWhatsThis(i18n("Close this window"));
+  a = actionCollection()->addAction( KStandardAction::Quit, "file_quit" );
+  // Qt::QueuedConnection: delay real shutdown, as we are inside menu action handling (bug #185708)
+  connect( a, SIGNAL( triggered() ), this, SLOT( slotFileQuit() ), Qt::QueuedConnection );
+  a->setWhatsThis(i18n("Close this window"));
 
   a = actionCollection()->addAction( "view_new_view" );
   a->setIcon( KIcon("window-new") );
@@ -390,30 +391,33 @@ void KateMainWindow::setupActions()
   a = actionCollection()->addAction( "sessions_new" );
   a->setIcon( KIcon("document-new") );
   a->setText( i18nc("Menu entry Session->New", "&New") );
-  connect( a, SIGNAL( triggered() ), KateSessionManager::self(), SLOT( sessionNew() ) );
+  // Qt::QueuedConnection to avoid deletion of code that is executed when reducing the amount of mainwindows. (bug #227008)
+  connect( a, SIGNAL( triggered() ), KateSessionManager::self(), SLOT( sessionNew() ), Qt::QueuedConnection );
   a = actionCollection()->addAction( "sessions_open" );
   a->setIcon( KIcon("document-open") );
-  a->setText( i18n("&Open...") );
-  connect( a, SIGNAL( triggered() ), KateSessionManager::self(), SLOT( sessionOpen() ) );
+  a->setText( i18n("&Open Session") );
+  // Qt::QueuedConnection to avoid deletion of code that is executed when reducing the amount of mainwindows. (bug #227008)
+  connect( a, SIGNAL( triggered() ), KateSessionManager::self(), SLOT( sessionOpen() ), Qt::QueuedConnection );
   a = actionCollection()->addAction( "sessions_save" );
   a->setIcon( KIcon("document-save") );
-  a->setText( i18n("&Save") );
+  a->setText( i18n("&Save Session") );
   connect( a, SIGNAL( triggered() ), KateSessionManager::self(), SLOT( sessionSave() ) );
   a = actionCollection()->addAction( "sessions_save_as" );
   a->setIcon( KIcon("document-save-as") );
-  a->setText( i18n("Save &As...") );
+  a->setText( i18n("Save Session &As...") );
   connect( a, SIGNAL( triggered() ), KateSessionManager::self(), SLOT( sessionSaveAs() ) );
   a = actionCollection()->addAction( "sessions_save_default" );
   a->setIcon( KIcon("document-save-as") );
-  a->setText( i18n("Save as &Default...") );
+  a->setText( i18n("Save Session as &Default...") );
   connect( a, SIGNAL( triggered() ), KateSessionManager::self(), SLOT( sessionSaveAsDefault() ) );
   a = actionCollection()->addAction( "sessions_manage" );
   a->setIcon( KIcon("view-choose") );
-  a->setText( i18n("&Manage...") );
-  connect( a, SIGNAL( triggered() ), KateSessionManager::self(), SLOT( sessionManage() ) );
+  a->setText( i18n("&Manage Sessions...") );
+  // Qt::QueuedConnection to avoid deletion of code that is executed when reducing the amount of mainwindows. (bug #227008)
+  connect( a, SIGNAL( triggered() ), KateSessionManager::self(), SLOT( sessionManage() ), Qt::QueuedConnection );
 
   // quick open menu ;)
-  a = new KateSessionsAction (i18n("&Quick Open"), this);
+  a = new KateSessionsAction (i18n("&Quick Open Session"), this);
   actionCollection()->addAction("sessions_list", a);
 }
 
@@ -430,6 +434,15 @@ void KateMainWindow::slotDocumentCloseOther(KTextEditor::Document *document)
     KateDocManager::self()->closeOtherDocuments(document);
 }
 
+void KateMainWindow::slotDocumentCloseSelected(const QList<KTextEditor::Document*> &docList)
+{
+  foreach(KTextEditor::Document *doc, docList)
+  {
+    if(queryClose_internal(doc))
+      KateDocManager::self()->closeDocument(doc);
+  }
+}
+
 void KateMainWindow::slotDocumentCloseOther()
 {
   if (queryClose_internal(m_viewManager->activeView()->document()))
@@ -511,13 +524,12 @@ void KateMainWindow::slotNewToolbarConfig()
 
 void KateMainWindow::slotFileQuit()
 {
-  // delay real shutdown outside of this, as we are inside menu action handling
-  QTimer::singleShot(0, this, SLOT(slotFileQuitDelayed()));
+  KateApp::self()->shutdownKate (this);
 }
 
-void KateMainWindow::slotFileQuitDelayed()
+void KateMainWindow::slotFileClose()
 {
-  KateApp::self()->shutdownKate (this);
+  m_viewManager->slotDocumentClose();
 }
 
 void KateMainWindow::readOptions ()
@@ -678,7 +690,7 @@ void KateMainWindow::slotDropEvent( QDropEvent * event )
       if (vs != 0) m_viewManager->setActiveSpace(vs);
     }
   }
-  
+
   for (KUrl::List::Iterator i = textlist.begin(); i != textlist.end(); ++i)
   {
     m_viewManager->openUrl (*i);
@@ -693,7 +705,7 @@ void KateMainWindow::editKeys()
 
   foreach(KXMLGUIClient *client, clients) {
 #ifdef __GNUC__
-#warning there appear to be invalid clients after session switching    
+#warning there appear to be invalid clients after session switching
 #endif
 //     kDebug(13001)<<"adding client to shortcut editor";
 //     kDebug(13001)<<client;
@@ -729,11 +741,19 @@ void KateMainWindow::openUrl (const QString &name)
 }
 
 void KateMainWindow::slotConfigure()
+{
+  showPluginConfigPage(0,0);
+}
+
+void KateMainWindow::showPluginConfigPage(Kate::PluginConfigPageInterface *configpageinterface,uint id)
 {
   if (!m_viewManager->activeView())
     return;
 
   KateConfigDialog* dlg = new KateConfigDialog (this, m_viewManager->activeView());
+  if (configpageinterface) {
+    dlg->showAppPluginPage(configpageinterface,id);
+  }
   dlg->exec();
 
   delete dlg;
@@ -914,7 +934,7 @@ void KateMainWindow::updateCaption (KTextEditor::Document *doc)
   if ( !sessName.isEmpty() )
     sessName = QString("%1: ").arg( sessName );
 
-  setCaption( sessName + KStringHandler::lsqueeze(c, 64),
+  setCaption( sessName + c,
               m_viewManager->activeView()->document()->isModified());
 }
 
@@ -965,6 +985,10 @@ void KateMainWindow::saveGlobalProperties( KConfig* sessionConfig )
 
   KConfigGroup cg( sessionConfig, "General");
   cg.writeEntry ("Last Session", KateApp::self()->sessionManager()->activeSession()->sessionFileRelative());
+
+  // save plugin config !!
+  KateApp::self()->pluginManager()->writeConfig (sessionConfig);
+  
 }
 
 void KateMainWindow::showFileListPopup(const QPoint& pos)
@@ -1014,7 +1038,7 @@ void KateMainWindow::restoreWindowConfig(const KConfigGroup &config)
 
 void KateMainWindow::slotUpdateHorizontalViewBar()
 {
-  kDebug()<<"slotUpdateHorizontalViewBar()"<<endl;
+  //kDebug()<<"slotUpdateHorizontalViewBar()"<<endl;
   KTextEditor::View *view=m_viewManager->activeView();
   BarState bs=m_viewBarMapping[view];
   if (bs.bar() && bs.state()) {
@@ -1024,7 +1048,7 @@ void KateMainWindow::slotUpdateHorizontalViewBar()
   } else {
     QWidget *wid=m_containerstack->currentWidget();
     if (wid) wid->hide();
-    kDebug()<<wid<<"hiding container"<<endl;
+    //kDebug()<<wid<<"hiding container"<<endl;
     m_horizontalViewBarContainer->hide();
   }
 }
@@ -1037,7 +1061,7 @@ void KateMainWindow::queueModifiedOnDisc(KTextEditor::Document *doc)
     DocVector list;
     list.reserve( KateDocManager::self()->documents() );
     list.append(doc);
-    
+
     s_modOnHdDialog= new KateMwModOnHdDialog( list, this );
     m_modignore = true;
     KWindowSystem::setOnAllDesktops( s_modOnHdDialog->winId(), true);
