@@ -33,6 +33,7 @@
 #include <QClipboard>
 #include <QRegExp>
 #include <QKeyEvent>
+#include <QtGui/QMenu>
 
 #include <kacceleratormanager.h>
 #include <kconfig.h>
@@ -65,6 +66,14 @@ KateResultView::KateResultView(Kate::MainWindow *mw, KateFindInFilesView *view)
   btnRefine->setGuiItem(KStandardGuiItem::find());
   btnRefine->setText(i18n("Refine Search..."));
 
+  QMenu* openMenu = new QMenu(btnOpen);
+  btnOpen->setMenu(openMenu);
+  btnOpen->setGuiItem(KStandardGuiItem::open());
+  btnOpen->setText(i18n("Open"));
+  openMenu->addAction(i18n("Open All Files"), this, SLOT(openAllFound()));
+  openMenu->addAction(i18n("Open Selected Files"), this, SLOT(openSelected()));
+
+
   // auto-accels
   KAcceleratorManager::manage(m_toolView);
 
@@ -74,7 +83,7 @@ KateResultView::KateResultView(Kate::MainWindow *mw, KateFindInFilesView *view)
                                "on the item to show the respective line in the editor."));
   setFocusProxy(twResults);
 
-  connect(twResults, SIGNAL(itemActivated(QTreeWidgetItem *, int)),
+  connect(twResults, SIGNAL(itemDoubleClicked(QTreeWidgetItem *, int)),
           this, SLOT(itemSelected(QTreeWidgetItem *, int)));
 
   connect(btnCancel, SIGNAL(clicked()), this, SLOT(killThread()));
@@ -134,7 +143,8 @@ void KateResultView::startSearch(KateFindInFilesOptions options,
                             url,
                             filter.split(QRegExp("[,;]"), QString::SkipEmptyParts),
                             m_options.recursive(),
-                            m_options.followDirectorySymlinks());
+                            m_options.followDirectorySymlinks(),
+                            m_options.includeHiddenFiles());
 }
 
 
@@ -211,6 +221,15 @@ void KateResultView::keyPressEvent(QKeyEvent *event)
     event->accept();
     return;
   }
+  if (event->key() == Qt::Key_Enter || event->key() == Qt::Key_Return)
+  {
+    if( !(twResults->selectedItems().empty()) )
+    {
+      itemSelected(twResults->currentItem(), 0);
+      event->accept();
+      return;
+    }
+  }
   QWidget::keyPressEvent(event);
 }
 
@@ -239,6 +258,37 @@ void KateResultView::refineSearch()
   dlg->show();
 }
 
+void KateResultView::openAllFound()
+{
+  QString lastFilename;
+  QString filename;
+  for (int i = 0; i < twResults->topLevelItemCount(); ++i )
+  {
+    QTreeWidgetItem *item = twResults->topLevelItem(i);
+    filename = item->data(0, Qt::UserRole).toString();
+    if ( filename != lastFilename )
+    {
+      itemSelected(item, 0);
+      lastFilename = filename;
+    }
+  }
+}
+
+void KateResultView::openSelected()
+{
+  QString lastFilename;
+  QString filename;
+  foreach( QTreeWidgetItem *item, twResults->selectedItems() )
+  {
+    filename = item->data(0, Qt::UserRole).toString();
+    if ( filename != lastFilename )
+    {
+      itemSelected(item, 0);
+      lastFilename = filename;
+    }
+  }
+}
+
 int KateResultView::id() const
 {
   return m_id;
