@@ -502,7 +502,8 @@ void PluginKateXMLToolsCompletionModel::slotInsertElement()
     return;
   }
 
-  PseudoDTD *dtd = m_docDtds[kv->document()];
+  KTextEditor::Document *doc = kv->document();
+  PseudoDTD *dtd = m_docDtds[doc];
   QString parentElement = getParentElement( *kv, 0 );
   QStringList allowed;
 
@@ -543,10 +544,19 @@ void PluginKateXMLToolsCompletionModel::slotInsertElement()
     if ( ! post.isEmpty() )
       marked = kv->selectionText();
 
-    if( marked.length() > 0 )
+    doc->startEditing();
+    
+    if( ! marked.isEmpty() )
       kv->removeSelectionText();
+    
+    KTextEditor::Cursor curPos = kv->cursorPosition(); // with the old selection now removed, curPos points to the start of pre
+    curPos.setColumn( curPos.column() + pre.length() - adjust );
 
     kv->insertText( pre + marked + post );
+
+    kv->setCursorPosition( curPos );
+    
+    doc->endEditing();
   }
 }
 
@@ -998,7 +1008,7 @@ InsertElement::InsertElement( QWidget *parent, const char *name )
 
   setCaption(i18n("Insert XML Element" ));
   setButtons(KDialog::Ok|KDialog::Cancel);
-  setDefaultButton(KDialog::Cancel);
+  setDefaultButton(KDialog::Ok);
   setModal(true);
 }
 
