@@ -33,7 +33,7 @@ class RdfProcessor : public DomProcessor
 
     KBB::Error parseDomBugList( const QDomElement &, Bug::List & );
 
-    void setBugListQuery( KURL &, const Package &, const QString &component );
+    void setBugListQuery( KUrl &, const Package &, const QString &component );
 };
 
 #endif
