@@ -62,7 +62,7 @@ QString BugLVI::key( int column, bool /* ascending */ ) const
     else if ( column == 1 )
     {
         if ( m_bug.age() == 0xFFFFFFFF )
-            key = "0";
+            key = '0';
         else
             key = QString::number( m_bug.age() ).rightJustified( 10, '0' );
     }
