@@ -8,7 +8,7 @@
   published by the Free Software Foundation; either version 2 of
   the License or (at your option) version 3 or any later version
   accepted by the membership of KDE e.V. (or its successor approved
-  by the membership of KDE e.V.), which shall act as a proxy 
+  by the membership of KDE e.V.), which shall act as a proxy
   defined in Section 14 of version 3 of the license.
 
   This program is distributed in the hope that it will be useful,
@@ -133,6 +133,10 @@ EditorTab::EditorTab(QWidget* parent, bool valid)
     connect(m_view, SIGNAL(tmLookupRequested(DocPosition::Part,QString)), this, SLOT(lookupSelectionInTranslationMemory()));
 
     connect(this, SIGNAL(fileOpened()), this, SLOT(indexWordsForCompletion()),Qt::QueuedConnection);
+
+    connect (m_catalog,SIGNAL(signalFileAutoSaveFailed(QString)),this,SLOT(fileAutoSaveFailedWarning(QString)));
+
+
     //defer some work to make window appear earlier (~200 msec on my Core Duo)
     //QTimer::singleShot(0,this,SLOT(initLater()));
     //kWarning()<<chrono.elapsed();
@@ -515,6 +519,10 @@ void EditorTab::setupActions()
     action->setShortcut(Qt::CTRL+Qt::Key_D);
     action->setText(i18nc("@action:inmenu","Clear"));
 
+    action=edit->addAction("edit_completion",m_view,SIGNAL(doExplicitCompletion()));
+    action->setShortcut(Qt::CTRL+Qt::ALT+Qt::Key_Space);
+    action->setText(i18nc("@action:inmenu","Completion"));
+
     action=edit->addAction("edit_tagmenu",m_view->viewPort(),SLOT(tagMenu()));
     action->setShortcut(Qt::CTRL+Qt::Key_T);
     action->setText(i18nc("@action:inmenu","Insert Tag"));
@@ -662,6 +670,7 @@ void EditorTab::setupActions()
     action->setStatusTip(i18nc("@info:status","This changes only empty and non-ready entries in base file"));
     action->setToolTip(action->statusTip());
     action->setWhatsThis(action->statusTip());
+    action->setShortcut(Qt::CTRL+Qt::ALT+Qt::Key_A);
     m_syncView->addAction(action);
     //action->setShortcut(Qt::ALT+Qt::Key_E);
 
@@ -896,6 +905,12 @@ bool EditorTab::saveFile(const KUrl& url)
     return false;
 }
 
+void EditorTab::fileAutoSaveFailedWarning(const QString& fileName)
+{
+    KMessageBox::information(this, i18nc("@info","Could not perform file autosaving.\n"
+                                                 "The target file was <filename>%1</filename>.", fileName) );
+}
+
 EditorState EditorTab::state()
 {
     EditorState state;
@@ -1283,7 +1298,6 @@ void EditorTab::indexWordsForCompletion()
     CompletionStorage::instance()->scanCatalog(m_catalog);
 }
 
-
 //see also termlabel.h
 void EditorTab::defineNewTerm()
 {
