@@ -29,25 +29,24 @@
 #include <QVector>
 #include <QLinkedList>
 
-
-/**
-* @short Structure
-*/
 struct MatchItem
 {
     short mergeEntry:16;
-    short score:15;
-    bool translationIsDifferent:1;
+    short baseEntry:16;
+    short score:16;
+    short translationIsDifferent:16;
 
     MatchItem()
     : mergeEntry(0)
+    , baseEntry(0)
     , score(0)
     , translationIsDifferent(false)
     {}
 
-    MatchItem(short m, short s, bool d)
+    MatchItem(short m, short b, bool d)
     : mergeEntry(m)
-    , score(s)
+    , baseEntry(b)
+    , score(0)
     , translationIsDifferent(d)
     {}
 
@@ -98,7 +97,7 @@ public:
 
     ///@arg pos in baseCatalog's coordinates
     void copyToBaseCatalog(DocPosition& pos);
-    enum CopyToBaseOptions {EmptyOnly=1};
+    enum CopyToBaseOptions {EmptyOnly=1, HigherOnly=2};
     void copyToBaseCatalog(int options=0);
 
     inline void removeFromDiffIndex(uint index){m_mergeDiffIndex.removeAll(index);}
