@@ -5,24 +5,36 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2002-2006                                               *
+ *   copyright (C) 2002-2007                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
 #include "umlnamespace.h"
-#include "qregexp.h"
+#include <qregexp.h>
+#include <kdebug.h>
 
 namespace Uml {
 
+/**
+ * Function for comparing tags in XMI files.
+ */
 bool tagEq (const QString& inTag, const QString& inPattern) {
     QString tag = inTag;
     QString pattern = inPattern;
     tag.remove( QRegExp("^\\w+:") );  // remove leading "UML:" or other
-    int patSections = pattern.contains( '.' ) + 1;
-    QString tagEnd = tag.section( '.', -patSections );
-    return (tagEnd.lower() == pattern.lower());
+    int patSections = pattern.count('.') + 1;
+    QString tagEnd = tag.section('.', -patSections);
+    return (tagEnd.toLower() == pattern.toLower());
 }
 
+/**
+ * Convert Visibility value into QString representation.
+ *
+ * @param value       Value to convert
+ * @param mnemonic    If true then return a single character:
+ *              "+" for public, "-" for private,
+ *              "#" for protected or "~" for implementation
+ */
 QString Visibility::toString(Value value, bool mnemonic) {
     switch (value) {
     case Protected:
@@ -64,6 +76,13 @@ Visibility::Visibility(): _v(Public) {
 Visibility::Visibility(Value v): _v(v) {
 }
 
+/**
+ * Convert Visibility value into QString representation.
+ *
+ * @param mnemonic    If true then return a single character:
+ *              "+" for public, "-" for private,
+ *              "#" for protected or "~" for implementation
+ */
 QString Visibility::toString(bool mnemonic) const {
     return toString(_v, mnemonic);
 }
